@@ -8,10 +8,4 @@ sub new {
 
 }
 
-sub d {
-
-	my ($self) = @_;
-
-}
-
 1;
